Project Description
===================

Emeral is a Python package for creating small games, developed based on Pygame, with the aim of changing the loop-refresh method to a multithreaded approach. The Emeral library is suitable for making 2D games and currently has four modules: display, events, image, and entity, with more modules planned for development. Emeral is currently in the beta version.


Installation
============

Before downloading the Emeral library, you must ensure that Python is already installed on your computer, and the Python version should be above 3.7. Version 3.7 is only the minimum requirement, and some advanced functions may not be available when using it. Once you have installed Python, you can use the following command to install the Emeral library from the command line.

.. code-block:: bash

   pip install emeral

After installing the Emeral library, you can use the following command to ensure that the library was installed successfully.

.. code-block:: bash

   pip list

If the Python library 'emeral' appears in the list, it means you have successfully installed it.


Help
====

Our documentation is actively being written. To view the basic help documentation, please write the following code in your Python program.

.. code-block:: python

   import emeral
   help(emeral)


Quick Start
===========

Basic framework:

.. code-block:: python

   import emeral

   window=emeral.display.Window() # Create a window object.

   room=emeral.display.Room(window) # Create a room on the window.
   room.set_caption("NewGame") # Set caption for the room, which will show on title bar.
   room.switch() # Switch to the window.

   window.listen() # Window Mainloop.


License
=======
MIT License - Check the LICENSE file for details.